package jmslexamples.jsyn2;

import java.awt.BorderLayout;
import java.awt.Button;
import java.awt.Checkbox;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.Panel;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JFrame;

import com.jsyn.swing.JAppletFrame;
import com.softsynth.jmsl.DataTranslator;
import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.JMSLMixerContainer;
import com.softsynth.jmsl.MusicDevice;
import com.softsynth.jmsl.MusicJob;
import com.softsynth.jmsl.MusicShape;
import com.softsynth.jmsl.jsyn2.JSynMusicDevice;
import com.softsynth.jmsl.jsyn2.JSynUnitVoiceInstrument;

/**
 * Alter performance data non-destructively using DataTranslator
 * 
 * Play a MusicShape with chromatic pitches.
 * 
 * Check a box to set/unset its DataTranslator to a WholeToneTranslator
 * 
 * @see com.softsynth.jmsl.DataTranslator
 * @see jmslexamples.jsyn2.DataTranslatorVectorDemo
 * 
 * @author Nick Didkovsky, email: nick@didkovsky.com, (c) 2003 Nick Didkovsky,
 *         all rights reserved.
 * 
 *         Upgraded to JSyn2 API Dec 2016
 * 
 */
public class DataTranslatorDemo extends JFrame implements ItemListener, ActionListener {

    MusicShape myShape;
    JMSLMixerContainer mixer;
    Button startButton;
    Button stopButton;
    Checkbox useTranslatorCheckbox;
 
    public void start() {
        setLayout(new BorderLayout());
        add(BorderLayout.NORTH, useTranslatorCheckbox = new Checkbox("Use Whole Tone Translator"));
        useTranslatorCheckbox.addItemListener(this);
        Panel p = new Panel();
        p.setLayout(new GridLayout(1, 2));
        p.add(startButton = new Button("START"));
        startButton.addActionListener(this);
        p.add(stopButton = new Button("STOP"));
        add(BorderLayout.SOUTH, p);
        stopButton.addActionListener(this);
        stopButton.setEnabled(false);
        buildMusic();
    }

    private void buildMusic() {
        JMSL.clock.setAdvance(0.1);
        MusicDevice dev = JSynMusicDevice.instance();
        dev.open();
        JSynUnitVoiceInstrument ins = new JSynUnitVoiceInstrument(4,
                com.softsynth.jmsl.jsyn2.unitvoices.FilteredSawtoothBL.class.getName());

        mixer = new JMSLMixerContainer();
        mixer.addInstrument(ins);
        mixer.start();

        myShape = new MusicShape(4);
        for (int i = 0; i < 13; i++) {
            myShape.add(0.25, i + 60, 0.5, 0.2);
        }
        myShape.setInstrument(ins);
        myShape.setRepeats(Integer.MAX_VALUE);
    }

    public void stop() {
        myShape.finishAll();
        removeAll();
        JMSL.closeMusicDevices();
    }

    public void itemStateChanged(ItemEvent arg0) {
        if (useTranslatorCheckbox.getState()) {
            System.out.println("Set translator");
            myShape.setDataTranslator(new WholeToneTranslator(60));
        } else {
            System.out.println("UNSet translator");
            myShape.setDataTranslator(null);
        }
    }

    public void actionPerformed(ActionEvent ev) {
        Object source = ev.getSource();
        if (source == startButton) {
            myShape.launch(JMSL.now());
            startButton.setEnabled(false);
            stopButton.setEnabled(true);
        }
        if (source == stopButton) {
            myShape.finishAll();
            stopButton.setEnabled(false);
            startButton.setEnabled(true);
        }
    }

    private class WholeToneTranslator implements DataTranslator {
        double centerPitch;

        public WholeToneTranslator(double centerPitch) {
            this.centerPitch = centerPitch;
        }

        public double[] translate(MusicJob job, double[] data) {
            // make a copy of the incoming double[]
            double[] dar = new double[data.length];
            System.arraycopy(data, 0, dar, 0, data.length);

            double difference = dar[1] - centerPitch;
            dar[1] = dar[1] + 2 * difference;
            return dar;
        }

    }

    public static void main(String[] args) {
        DataTranslatorDemo demo = new DataTranslatorDemo();
        demo.setSize(200, 200);
        demo.setVisible(true);
        demo.setLayout(new FlowLayout());
        demo.start();
        demo.pack();
    }
}
