package jmslexamples.jsyn2;

import java.awt.Graphics;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;

import com.didkovsky.portview.swing.ViewFactorySwing;
import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.jsyn2.JSynMusicDevice;
import com.softsynth.jmsl.jsyn2.JSynUnitVoiceInstrument;
import com.softsynth.jmsl.score.Orchestra;
import com.softsynth.jmsl.score.Score;
import com.softsynth.jmsl.score.ScoreFrame;

/**
 * Score with a JSynUnitVoiceInstrument orchestra <br>
 * 
 * Double click on a note to edit its timbre <br>
 * This instrument takes a UnitVoice class name and max voices in its
 * constructor, and will make each input port editable
 * 
 * 
 * 
 * @author Nick Didkovsky, copyright 2000 Nick Didkovsky
 */
public class PolyTimbralScoreDemo extends JFrame {

    Score score;
    ScoreFrame scoreFrame;
    Orchestra orch;

    public void start() {
        initMusicDevices();
        initJMSL();
        buildOrchestra();
        buildScore();
        buildScoreFrame();
    }

    private void buildScoreFrame() {
        scoreFrame = new ScoreFrame(
                "PolyTimbral JMSL Score JSyn Demo by Nick Didkovsky, copyright 2000 Nick Didkovsky");
        scoreFrame.addScore(score);
        // force netscape to size window ok
        scoreFrame.setSize(score.getLayoutWidth() + 100, score.getLayoutHeight() + 100);
        scoreFrame.setVisible(true);
    }

    private void buildScore() {
        int w = 1000;
        int h = 600;
        int numStaves = 4;
        score = new Score(numStaves, w, h, "JMSL Score JSyn Demo");
        score.setComposer("Nick Didkovsky");
        score.setCopyright("(c) 2016 Nick Didkovsky");
        score.setScoreSubtitle("Add notes with mouse (Command click or right click on staff). Double click on a note to edit its synth params");
        score.addMeasure();
        score.setOrchestra(orch);
        score.getScoreLayoutManager().setZoom(0.5);
        score.getControlPanel().setZoom(0.5);
    }

    private void buildOrchestra() {
        orch = new Orchestra();
        String unitVoiceClassName = com.softsynth.jmsl.jsyn2.unitvoices.FilteredSawtoothBL.class.getName();
        orch.addInstrument(new JSynUnitVoiceInstrument(8, unitVoiceClassName), "Bob");
        orch.addInstrument(new JSynUnitVoiceInstrument(8, unitVoiceClassName), "Fran");
        orch.addInstrument(new JSynUnitVoiceInstrument(8, unitVoiceClassName), "Jimbo");
        orch.addInstrument(new JSynUnitVoiceInstrument(8, unitVoiceClassName), "Toots");
        orch.getJMSLMixerContainer().panAmpChange(2, 0.1, 0.9);
    }

    private void initJMSL() {
        JMSL.setViewFactory(new ViewFactorySwing());
        JMSL.clock.setAdvance(0.3);
    }

    private void initMusicDevices() {
        JSynMusicDevice.instance().open();
    }

    public ScoreFrame getScoreFrame() {
        return scoreFrame;
    }

    
    public void paint(Graphics g) {
        g.drawString("Your score has been opened in a Frame outside this browser", 20, 20);
        g.drawString("Add notes with mouse (right click / command click on staff).", 20, 50);
        g.drawString("Double click on a note to edit its synthesis parameters", 20, 80);
    }

    /* Can be run as either an application or as an applet. */
    public static void main(String args[]) {
        PolyTimbralScoreDemo demo = new PolyTimbralScoreDemo();
        
        demo.setSize(600,200);
        demo.setVisible(true);
        demo.start();
        demo.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                JMSL.closeMusicDevices();
                System.exit(0);
            }
        });
    }

}