package jmsltestsuite;

import java.awt.*;
import java.awt.event.*;
import java.io.IOException;

import javax.swing.*;

import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.score.musicglyphrenderers.BravuraFontConstants;

/**
 * Displays Bravura Font characters in a JPanel.
 * 
 * @author Nick Didkovsky, (c) 2014 Nick Didkovsky
 * 
 */

public class BravuraFontTest extends JPanel {

	private Font bravuraFont;

	private Font timesFont = new Font("TimesRoman", Font.PLAIN, 12);

	public void lookupBravuraFont() throws FontFormatException, IOException {
		GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
		System.out.println("FONTS");
		Font[] fonts = ge.getAllFonts();
		for (int i = 0; i < fonts.length; i++) {
			String fontName = fonts[i].getFontName();
			System.out.println(fontName);
			if (fontName.equalsIgnoreCase("Bravura")) {
				bravuraFont = fonts[i].deriveFont(Font.PLAIN, 22f);
				System.out.println("Found your font: " + fontName + "!");
				break;
			}
		}
	}

	String[] bravuraSymbols = { "\uE032", "\uE040", "\uE048", "\uE050", "\uE0A4", "\uE0A3", "\uE0A2", "\uE0A0", "\uE0AA", "\uE260", "\uE262",
			"\uE261", "\uE520", "\uE522", "\uE56E", "\uE230", "\uE202", BravuraFontConstants.SIXTYFOURTH_FLAG_DOWN };

	String[] bravuraSymbolsFriendly = { "E032", "E040", "E048", "E050", "E0A4", "E0A3", "E0A2", "E0A0", "E0AA", "E260", "E262",
			"E261", "E520", "E522", "E56E", "E230", "E202", "64down" };

	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		if (bravuraFont != null) {
			FontMetrics fm = this.getFontMetrics(bravuraFont);
			int numChars = 256;
			int numPerColumn = 20;
			int colWidth = 90;
			int leftMargin = 40;
			int topMargin = 20;
			int rowHeight = 40;
			for (int i = 0; i < bravuraSymbols.length; i++) {
				int x = leftMargin + i / numPerColumn * colWidth;
				int y = i % numPerColumn * rowHeight + topMargin;

				g.setFont(bravuraFont);
				String musicGlyph = bravuraSymbols[i];
				int widthOfMusicGlyph = (int) fm.getStringBounds(musicGlyph, g).getWidth();
				g.drawString(musicGlyph, x, y);
				g.setFont(timesFont);
				String s = i + " [\\u" + bravuraSymbolsFriendly[i] + "]";
				g.drawString(s, x + widthOfMusicGlyph + 10, y);
			}
		} else {
			String err = "No font found";
			g.drawString(err, 20, 20);
			System.err.println(err);
		}

	}

	JTextField charTextField;
	JButton nextButton;
	JButton prevButton;
	int currentChar = 80;

	void buildCharShower() {
		final JPanel charPanel = new JPanel() {
			public void paintComponent(Graphics g) {
				super.paintComponent(g);
				if (bravuraFont != null) {
					g.setFont(bravuraFont.deriveFont(Font.PLAIN, 50));
					g.drawString(((char) currentChar) + "", 50, 100);
					g.drawString("\u00DF", 150, 100); // mezzo is 194 189 BDC2
				}
			}
		};
		charPanel.setPreferredSize(new Dimension(150, 200));
		JPanel controlPanel = new JPanel();
		controlPanel.setLayout(new FlowLayout());
		controlPanel.add(prevButton = new JButton("<"));
		controlPanel.add(charTextField = new JTextField(currentChar + "", 3));
		controlPanel.add(nextButton = new JButton(">"));

		prevButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				currentChar--;
				charTextField.setText(currentChar + "");
				charPanel.repaint();
			}
		});

		nextButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				currentChar++;
				charTextField.setText(currentChar + "");
				charPanel.repaint();
			}
		});

		charTextField.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				currentChar = new Integer(charTextField.getText().trim()).intValue();
				charPanel.repaint();
			}
		});

		JFrame j = new JFrame("Show character");
		j.setLayout(new BorderLayout());
		j.add(BorderLayout.NORTH, charPanel);
		j.add(BorderLayout.SOUTH, controlPanel);
		j.pack();
		j.setVisible(true);
	}

	public static void main(String[] args) {
		JFrame jf = new JFrame("Bravura font in Java");
		BravuraFontTest ft = new BravuraFontTest();
		try {
			// String fontName = "Sonata";
			// String fontName = "Bravura";
			String fontName = "Maestro";
			// String fontName = "Accidentals";
			ft.lookupBravuraFont();
			// ft.buildFontExplicitely(fontName);
		} catch (FontFormatException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		ft.setPreferredSize(new Dimension(1424, 900));
		jf.getContentPane().add(ft);
		jf.pack();
		jf.setVisible(true);
		jf.addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				JMSL.closeMusicDevices();
				System.exit(0);
			}
		});
		// ft.buildCharShower();
	}
}
