/*
 * Created on Mar 12, 2007 by Nick
 *
 */
package jmsltestsuite;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import com.softsynth.jmsl.score.*;

/**
 * Receive notice of notes being added to a score by hand, notes being pasted, and ScoreCommands
 * being executed
 * 
 * Also received notice of measures being added, inserted, or deleted
 * 
 * for Peter McCullough's PhD research in tracking compositional process
 * 
 * @author Nick Didkovsky, (c) 2005 Nick Didkovsky, nick@didkovsky.com
 * 
 */
public class ScoreEditManagerListenerTest implements EditManagerListener {

    // this would be advanced and delivered from database
    public static int primaryKeyID = 0;

    public void addNote(Score score, double dur, int pitch, double amp, double hold) {
        Note n = score.addNote(dur, pitch, amp, hold);
        assignNewPrimaryKeyToNote(n);
    }

    void printPrimaryKeyOfNote(Note note) {
        if (note.getUserBeans() != null && note.getUserBeans().size() > 0) {
            Object bean = note.getUserBeans().elementAt(0);
            if (bean instanceof UserBeansTest) {
                System.out.println(bean.toString());
            }
        } else {
            System.out.println("This note has no user beans");
        }
    }

    private void assignNewPrimaryKeyToNote(Note note) {
        UserBeansTest primaryKey = new UserBeansTest();
        primaryKey.setId(primaryKeyID++);
        if (note.getUserBeans() != null && note.getUserBeans().size() > 0) {
            Object bean = note.getUserBeans().elementAt(0);
            if (bean instanceof UserBeansTest) {
                note.removeUserBean(bean);
            }
        }
        note.addUserBean(primaryKey);
    }

    /** EditManagerListener interface */
    public void noteInserted(Score score, Note note) {
        System.out.println("Note inserted");
        assignNewPrimaryKeyToNote(note);
        printPrimaryKeyOfNote(note);
    }

    /** EditManagerListener interface */
    public void notePasted(Score score, Note originalNote, Note clonedNote) {
        assignNewPrimaryKeyToNote(clonedNote);
        System.out.println("Note pasted");
        System.out.print("original note: ");
        printPrimaryKeyOfNote(originalNote);
        System.out.print("cloned & pasted note: ");
        printPrimaryKeyOfNote(clonedNote);
    }

    /** EditManagerListener interface */
    public void scoreCommandExecuted(Score score, ScoreCommand scoreCommand) {
        System.out.println("EditManager executed ScoreCommand " + scoreCommand.getName());
        if (scoreCommand instanceof NotePropertiesTransformCommand) {
            System.out.println("That's a NotePropertiesTransform so inspect selection buffer");
        } else if (scoreCommand instanceof UnaryCopyBufferTransformCommand) {
            System.out.println("That's a UnaryCopyBufferTransformCommand so inspect copy buffer");
        } else if (scoreCommand instanceof BinaryCopyBufferTransformCommand) {
            System.out.println("That's a BinaryCopyBufferTransformCommand so inspect aux copy buffers");
        }
    }


    public void measureAdded(Score score, Measure measure) {
        System.out.println("measure added, score.size()=" + score.size());
    }

    public void scoreCommandUndo(Score score, ScoreCommand scoreCommand) {
        System.out.println("EditManager executed ScoreCommand UNDO " + scoreCommand.getName());
        
    }

    public void scoreCommandRedo(Score score, ScoreCommand scoreCommand) {
        System.out.println("EditManager executed ScoreCommand REDO " + scoreCommand.getName());
        
    }

    public static void main(String[] args) {
        ScoreEditManagerListenerTest scoreEditManagerListenerTest = new ScoreEditManagerListenerTest();
        EditManager.addScoreEditManagerListener(scoreEditManagerListenerTest);
        Score score = new Score(1, 1000, 200);
        score.addMeasure();

        // add couple of notes programmatically, which assigns primary keys to them
        scoreEditManagerListenerTest.addNote(score, 1.0, 60, 0.5, 0.8);
        scoreEditManagerListenerTest.addNote(score, 1.0, 62, 0.5, 0.8);

        ScoreFrame scoreFrame = new ScoreFrame();
        scoreFrame.addScore(score);
        scoreFrame.pack();
        scoreFrame.setVisible(true);
        scoreFrame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });
        System.out.println("Insert notes with the mouse. Copy, paste, transform them by hand and watch console");
    }
   

}
