package jmsltestsuite;

import java.applet.Applet;
import java.net.MalformedURLException;
import java.net.URL;

import com.softsynth.jmsl.DefaultMusicClock;
import com.softsynth.jmsl.EventScheduler;
import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.JMSLMixerContainer;
import com.softsynth.jmsl.JMSLRandom;
import com.softsynth.jmsl.MusicShape;
import com.softsynth.jmsl.ParallelCollection;
import com.softsynth.jmsl.midi.MidiIO_JavaSound;
import com.softsynth.jmsl.midi.MidiInstrument;
import com.softsynth.jmsl.view.MusicShapeEditor;

/**
 * Play a simple two note MIDI melody with long tones, and send pitchbend while
 * notes are sustaining. Change contour of pitchbend shape in MusicShapeEditor.
 * For Fadi Ghawanmeh
 * 
 * @author Nick Didkovsky 2011-12-05
 * 
 * */

public class TestPitchBendInstrument extends Applet {

	JMSLMixerContainer mixer;
	MidiInstrument instrument;
	PitchBendInstrument pitchbendInstrument;

	MusicShape melody;
	MusicShape pitchbendShape;

	ParallelCollection mySong;

	public void init() {
		// JMSL.setIsApplet(true);
	}

	public void start() {
		synchronized (JMSL.class) {
			initJMSL();
			initMusicDevices();
			buildMixer();
			buildInstrument();
			buildSong();
			buildMusicShapeEditor();
			launchSong();
		}
	}

	private void buildMusicShapeEditor() {
		MusicShapeEditor se = new MusicShapeEditor();
		se.addMusicShape(pitchbendShape);
		se.addMusicShape(melody);
		add(se.getComponent());
	}

	private void initJMSL() {
		JMSL.scheduler = new EventScheduler();
		JMSL.scheduler.start();
		JMSL.clock.setAdvance(0.1);
	}

	private void initMusicDevices() {
		JMSL.clock = new DefaultMusicClock();
		initJavaSoundMidi();
	}

	private void initJavaSoundMidi() {
		JMSL.midi = MidiIO_JavaSound.instance();
		try {
			((MidiIO_JavaSound) JMSL.midi).setSoundbankURL(new URL(getCodeBase(), "javasound/soundbank-min.gm"));
		} catch (MalformedURLException e) {
			e.printStackTrace();
		}
		JMSL.midi.edit(new java.awt.Frame());
		JMSL.midi.open();
	}

	private void buildMixer() {
		mixer = new JMSLMixerContainer();
		mixer.start();
	}

	private void buildInstrument() {
		instrument = new MidiInstrument(1);
		instrument.setProgram(65);
		mixer.addInstrument(instrument);

		pitchbendInstrument = new PitchBendInstrument(1);
		mixer.addInstrument(pitchbendInstrument);

	}

	void buildSong() {

		melody = new MusicShape(4);
		melody.setName("Melody");
		melody.useStandardDimensionNameSpace();
		melody.setInstrument(instrument);
		melody.add(5, 50, 90, 4.8);
		melody.add(5, 62, 90, 4.8);
		melody.setRepeats(10000);

		pitchbendShape = new MusicShape(pitchbendInstrument.getDimensionNameSpace());
		pitchbendShape.setName("pitchbend");
		double lowLimit = pitchbendInstrument.getDimensionNameSpace().getLowLimit(1);
		double highLimit = pitchbendInstrument.getDimensionNameSpace().getHighLimit(1);
		for (int i = 0; i < 50; i++) {
			pitchbendShape.add(0.1, JMSLRandom.choose(lowLimit, highLimit));
		}
		pitchbendShape.setInstrument(pitchbendInstrument);
		pitchbendShape.setRepeats(2000);

		mySong = new ParallelCollection();

		mySong.add(melody);
		mySong.add(pitchbendShape);

	}

	private void launchSong() {
		mySong.launch(JMSL.now());
	}

	public void stop() {
		synchronized (JMSL.class) {
			mySong.finishAll();
			try {
				mySong.waitForDone();
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
			JMSL.scheduler.stop();
			JMSL.closeMusicDevices();
		}
	}
}
