package jmsltestsuite;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.IOException;
import java.util.*;

import com.softsynth.jmsl.score.*;
import com.softsynth.jmsl.score.transforms.NoteVisibleTransform;

public class TortureNoteVisibility {
    Score score;
    ScoreFrame scoreFrame;

    ArrayList<Note> notes = new ArrayList<Note>();

    void buildScore() {
        score = new Score(1, 1100, 800);
        score.addMeasure();
        for (int i = 0; i < 50000; i++) {
            notes.add(score.addNote(0.25, 60, 0.5, 0.8));
        }

        scoreFrame = new ScoreFrame();
        scoreFrame.addScore(score);
        scoreFrame.pack();
        scoreFrame.setVisible(true);
        scoreFrame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            };
        });
    }

    void setBunchInvisible(boolean v) {
        long millis = System.currentTimeMillis();
        for (int i = 0; i < notes.size(); i++) {
            Note note = notes.get(i);
            note.setVisible(v);
        }
        score.render();
        System.out.println("setBunchInvisible, " + notes.size() + " notes, " + v + " took "
                + (System.currentTimeMillis() - millis) + " millis");
    }

    void setBunchInvisibleBySelecting(boolean flag) {
        long millis = System.currentTimeMillis();
        score.getSelectionBuffer().deselectAndClear();
        for (int i = 0; i < notes.size(); i++) {
            Note note = notes.get(i);
//            if (!score.getSelectionBuffer().contains(note)) {
                score.getSelectionBuffer().addElement(note);
                note.setSelected(true);
//            }
        }
        NoteVisibleTransform transform = new NoteVisibleTransform(flag);
        NotePropertiesTransformCommand cmd = new NotePropertiesTransformCommand(transform);
        cmd.setScore(score);
        score.getEditManager().executeScoreCommand(cmd);
        score.render();
        System.out.println(notes.size() + " notes, " + transform.getName() + " took "
                + (System.currentTimeMillis() - millis) + " millis");
    }

    void copyNotesToVector() {
        long millisBefore = System.currentTimeMillis();
        Vector v = new Vector();
        for (int i = 0; i < notes.size(); i++) {
            Note note = notes.get(i);
            if (!v.contains(note)) {
                v.addElement(note);
            }
        }
        long millisAfter = System.currentTimeMillis();
        System.out.println("copyNotesToVector() took " + (millisAfter - millisBefore) + " millis");
    }

    void copyNotesToArrayList() {
        long millisBefore = System.currentTimeMillis();
        ArrayList<Note> v = new ArrayList<Note>();
        for (int i = 0; i < notes.size(); i++) {
            Note note = notes.get(i);
            if (!v.contains(note)) {
                v.add(note);
            }
        }
        long millisAfter = System.currentTimeMillis();
        System.out.println("copyNotesToArrayList() took " + (millisAfter - millisBefore) + " millis");
    }
    
    void copyNotesToHashtable() {
        long millisBefore = System.currentTimeMillis();
        Hashtable<Note, Boolean> v = new  Hashtable<Note, Boolean>();
        for (int i = 0; i < notes.size(); i++) {
            Note note = notes.get(i);
            if (!v.containsKey(note)) {
                v.put(note, Boolean.TRUE);
            }
        }
        long millisAfter = System.currentTimeMillis();
        System.out.println("copyNotesToHashtable() took " + (millisAfter - millisBefore) + " millis");
    }

    void saveScoreXML() {
        try {
            long millisBefore = System.currentTimeMillis();
            score.save("C:\\Users\\nick\\Desktop\\test.xml");
            long millisAfter = System.currentTimeMillis();
            System.out.println("saveScoreXML() took " + (millisAfter - millisBefore) + " millis");
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    void saveScoreZIP() {
        try {
            long millisBefore = System.currentTimeMillis();
            score.save("C:\\Users\\nick\\Desktop\\test.zip");
            long millisAfter = System.currentTimeMillis();
            System.out.println("saveScoreZIP() took " + (millisAfter - millisBefore) + " millis");
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void main(String[] args) {
        TortureNoteVisibility torture = new TortureNoteVisibility();
        torture.buildScore();
        try {
            Thread.sleep(1000);
        } catch (InterruptedException e) {

        }
        // torture.setBunchInvisible(false);
        torture.setBunchInvisibleBySelecting(false);
        try {
            Thread.sleep(1000);
        } catch (InterruptedException e) {

        }
        // torture.setBunchInvisible(true);
        torture.setBunchInvisibleBySelecting(true);
        torture.saveScoreXML();
        torture.saveScoreZIP();
        
        torture.copyNotesToVector();
        torture.copyNotesToArrayList();
        torture.copyNotesToHashtable();
    }

}
