package jmsltestsuite;

import java.util.Vector;

import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.MusicShape;
import com.softsynth.jmsl.score.Note;
import com.softsynth.jmsl.score.NoteFactory;
import com.softsynth.jmsl.score.Score;
import com.softsynth.jmsl.score.ScoreFrame;
import com.softsynth.jmsl.score.Staff;
import com.softsynth.jmsl.score.Tempo;
import com.softsynth.jmsl.score.transcribe.BeatDivisionSchemeList;
import com.softsynth.jmsl.score.transcribe.ElementMissedException;
import com.softsynth.jmsl.score.transcribe.SearchPathListExpansionException;
import com.softsynth.jmsl.score.transcribe.TempoTimeSignatureHolder;
import com.softsynth.jmsl.score.transcribe.Transcriber;
import com.softsynth.jmsl.score.transcribe.TranscriberListener;
import com.softsynth.jmsl.util.TimeSignature;

/**


			
 * @author Nick Didkovsky, (c) 2011 Nick Didkovsky, All Rights reserved.
 */

public class TranscribeScore17 {

	public static void main(String args[]) {
		JMSL.clock.setAdvance(0.1);
		BeatDivisionSchemeList.defaultSetup();

		
		MusicShape sourceBug = new MusicShape(4);
		sourceBug.add(0.5, 60.0, 0.5, 2.0 );
		sourceBug.add(3.5, 54.0, 0.5, 1.0 );	

		// 1 staff, width, height
		Score score = new Score(1, 1024, 800);
		score.addMeasure();
		
		Transcriber transcriber = new Transcriber();
		transcriber.setExtendLastHoldTime(true);
		transcriber.setScore(score);

		transcriber.addTranscriberListener(new TranscriberListener () {

			public void noteAdded(Score score, Note note) {
				if (note.isRest()) {
					System.out.println("That's a rest, dur=" + note.getDurationData());
					note.setText("sect. st. ");
					setLyricTextLevel(note);
					note.setMark(Note.MARK_WEDGE);
				} else {
					if (note.getPitchData() == 60) {
						note.setNoteHeadType(Note.NOTEHEAD_X);
					}
				}			
			}

			void setLyricTextLevel(Note note) {
				int offset = 40;
				if (note.getLevel() >= NoteFactory.LEVEL_OF_MIDDLE_C) {
					offset = (note.getLevel() - NoteFactory.LEVEL_OF_MIDDLE_C + 8)
							* Staff.SPACE_INTERVAL / 2;
				}
				note.setTextOffsetY(offset);
			}
			
			public void notifyCarriedOverMusicShape(Score score, int currentMeasureNumber, MusicShape musicShape) {
				
			}});
		transcriber.setSourceMusicShape(sourceBug);

		Vector tsVector = new Vector();
		tsVector.addElement(new TempoTimeSignatureHolder(new Tempo(60), new TimeSignature(2, 4)));

		transcriber.setTempoTimeSignatures(tsVector);

		try {
			score.setCurrentStaffNumber(0);
			transcriber.transcribe();
		} catch (ElementMissedException e) {
			e.printStackTrace();
			System.out.println("ERROR: " + e);
			System.exit(0);
		} catch (SearchPathListExpansionException e) {
			e.printStackTrace();
			System.out.println("ERROR: " + e);
			System.exit(0);
		}

		final ScoreFrame f = new ScoreFrame();
		f.addScore(score);
		// f.loadPrefs();
		f.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				f.quit();
			}
		});

		f.setVisible(true);

	}

}
