package jmsltestsuite;

import java.util.Vector;

import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.MusicShape;
import com.softsynth.jmsl.score.Note;
import com.softsynth.jmsl.score.Score;
import com.softsynth.jmsl.score.ScoreFrame;
import com.softsynth.jmsl.score.Tempo;
import com.softsynth.jmsl.score.transcribe.BeatDivisionSchemeList;
import com.softsynth.jmsl.score.transcribe.ElementMissedException;
import com.softsynth.jmsl.score.transcribe.SearchPathListExpansionException;
import com.softsynth.jmsl.score.transcribe.TempoTimeSignatureHolder;
import com.softsynth.jmsl.score.transcribe.Transcriber;
import com.softsynth.jmsl.score.transcribe.TranscriberListener;
import com.softsynth.jmsl.util.TimeSignature;

/**

Use a fifth dimension to mark certain notes for conversion to rests with wedge. For Larry Polansky
			
 * @author Nick Didkovsky, (c) 2011 Nick Didkovsky, All Rights reserved.
 */

public class TranscribeScore18 {

	public static void main(String args[]) {
		JMSL.clock.setAdvance(0.1);
		BeatDivisionSchemeList.defaultSetup();

		int LEAVE_ME_ALONE = 0;
		int CHANGE_ME_TO_A_REST_WITH_WEDGE = 1;
		
		MusicShape source = new MusicShape(5);
		source.add(0.5, 60.0, 0.5, 0.5, LEAVE_ME_ALONE );
		source.add(1.5, 54.0, 0.5, 0.5, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		source.add(2.0, 54.0, 0.5, 1.0, LEAVE_ME_ALONE );	
		source.add(3.5, 54.0, 0.5, 1.0, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		source.add(4.0, 54.0, 0.5, 1.0, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		
		// the following elements are meaningless to the Transcriber as they are just rests. 
		// Do not affect results other than to extend the end of the score by a few measures.		 
		source.add(4.5, 0.0, 0.5, 1.0, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		source.add(5.5, 0.0, 0.5, 1.0, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		source.add(6, 0.0, 0.5, 1.0, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		source.add(7, 0.0, 0.5, 1.0, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		source.add(8, 0.0, 0.5, 1.0, CHANGE_ME_TO_A_REST_WITH_WEDGE );	
		
		// 1 staff, width, height
		Score score = new Score(1, 1024, 800);
		score.addMeasure();
		
		Transcriber transcriber = new Transcriber();
		transcriber.setExtendLastHoldTime(true);
		transcriber.setScore(score);

		transcriber.addTranscriberListener(new TranscriberListener () {

			public void noteAdded(Score score, Note note) {
				if (note.getPerformanceData()[4] == 1) {
					System.out.println("Making that a rest, dur=" + note.getDurationData());
					note.setPitchData(0);
					note.addMark(Note.MARK_WEDGE);
				} 
			}			
			
			public void notifyCarriedOverMusicShape(Score score, int currentMeasureNumber, MusicShape musicShape) {
				
			}});
		transcriber.setSourceMusicShape(source);

		Vector tsVector = new Vector();
		tsVector.addElement(new TempoTimeSignatureHolder(new Tempo(60), new TimeSignature(2, 4)));
		transcriber.setTempoTimeSignatures(tsVector);

		try {
			score.setCurrentStaffNumber(0);
			transcriber.transcribe();
		} catch (ElementMissedException e) {
			e.printStackTrace();
			System.out.println("ERROR: " + e);
			System.exit(0);
		} catch (SearchPathListExpansionException e) {
			e.printStackTrace();
			System.out.println("ERROR: " + e);
			System.exit(0);
		}

		final ScoreFrame f = new ScoreFrame();
		f.addScore(score);
		// f.loadPrefs();
		f.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				f.quit();
			}
		});

		f.setVisible(true);

	}

}
