package jmsltestsuite;

import java.util.Vector;

import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.MusicShape;
import com.softsynth.jmsl.score.*;
import com.softsynth.jmsl.score.transcribe.*;
import com.softsynth.jmsl.util.TimeSignature;

/**
 * 
 * 
 * This examines dimension name space, and tests fix of a bug that added rests with 0 instead of default values for extended dimensions
 * 
 * 
 * 
 @author Nick Didkovsky, (c) 2002 Nick Didkovsky, All Rights reserved.
 */

public class TranscribeScore22 {

    public static void main(String args[]) {
        JMSL.clock.setAdvance(0.1);
        BeatDivisionSchemeList.defaultSetup();

        MusicShape source1 = new MusicShape(5);
        source1.useStandardDimensionNameSpace();
        source1.setDimName(4, "extra_dim");
        source1.setDefault(4, 50);
        source1.setLimits(4, 10, 100);
        source1.add(0., 65, 0.5, 4., 11);
        source1.add(4., 65, 0.5, 2, 99);
        source1.add(8., 65, 0.5, 2, 51);

        Score score = new Score(1, 1024, 800);
        score.addMeasure();

        Transcriber transcriber = new Transcriber();

        Vector tsVector = new Vector();
        tsVector.addElement(new TimeSignature(4, 4));
        transcriber.setTimeSignatures(tsVector);

        try {
            score.setCurrentStaffNumber(0);
            transcriber.setScore(score);
            score.rewind();
            transcriber.setSourceMusicShape(source1);
            transcriber.transcribe();

        } catch (ElementMissedException e) {
            e.printStackTrace();
            System.out.println("ERROR: " + e);
            System.exit(0);
        } catch (SearchPathListExpansionException e) {
            e.printStackTrace();
            System.out.println("ERROR: " + e);
            System.exit(0);
        }

        for (int m = 0; m < score.size(); m++) {
            Measure measure = score.getMeasure(m);
            for (int n = 0; n < measure.getStaff(0).getTrack(0).size(); n++) {
                Note note = measure.getStaff(0).getTrack(0).getNote(n);
                double[] data = note.getData();
                System.out.println("measure " + m + ", note " + n);
                JMSL.printDoubleArray(data);
            }
        }
        final ScoreFrame f = new ScoreFrame();
        f.addScore(score);
        f.addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent e) {
                f.quit();
            }
        });

        f.setVisible(true);

    }

}
