/**
 * Add algorithmically generated notes to a JMSL score. Notice that when there
 * are more notes than there are measures to accomodate them, that measures are
 * added as needed.
 * 
 * @author Phil Burk and Nick Didkovsky
 */
/*
 * (C) 1997 Phil Burk and Nick Didkovsky, All Rights Reserved JMSL is based upon
 * HMSL (C) Phil Burk, Larry Polansky and David Rosenboom.
 */

package jmsltutorial;

import java.awt.Color;
import java.awt.Label;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;

import com.softsynth.jmsl.DefaultMusicClock;
import com.softsynth.jmsl.EventScheduler;
import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.JMSLRandom;
import com.softsynth.jmsl.score.Note;
import com.softsynth.jmsl.score.NoteFactory;
import com.softsynth.jmsl.score.Score;
import com.softsynth.jmsl.score.ScoreFrame;
import com.softsynth.jmsl.score.SelectionBuffer;

public class JScoreToot02 extends JFrame {

    Score score;
    ScoreFrame scoreFrame;

    /*
     * Build data, and send JMSL's STDOut to a TextArea
     */
    public void init() {
        setBackground(Color.yellow);
        add(new Label("Your JMSL score will open in a new window"));
    }

    /** generate 40 random notes and add to current staff # */
    void generateNotes() {
        int[] possibleIntervals = { 3, 4, 7, 9, 12 };
        int numNotes = 40;
        for (int i = 0; i < numNotes; i++) {
            double dur = 0.25;
            Note note = score.addNote(dur, NoteFactory.MIDDLE_C + JMSLRandom.choose(12), 0.5, dur * 0.8);
            note.setBeamedOut(i % 2 == 0); // beam out even numbered notes
            // occasionally add an interval above the last added note.
            if (JMSLRandom.choose(4) == 0)
                note.addInterval(possibleIntervals[JMSLRandom.choose(possibleIntervals.length)] + note.getPitchData());
        }

    }

    public void start() {
        JMSL.clock.setAdvance(0.1);
        
        // 2 staves, width, height
        score = new Score(2, 800, 400);
        scoreFrame = new ScoreFrame();
        scoreFrame.addScore(score);

        score.addMeasure(10, 16);
        score.addMeasure(3, 4);
        score.addMeasure(3, 8);
        score.addMeasure(5, 8);
        // now add some algorithmically generated notes.
        // default insertion point is measure 0, staff 0
        generateNotes();
        score.rewind();
        score.setCurrentStaffNumber(1);
        generateNotes();
        scoreFrame.setVisible(true);
        scoreFrame.setSize(900, 600);
        score.render();
    }

    /* When applet stops, hide the scoreframe */
    public void stop() {
        if (scoreFrame != null) {
            scoreFrame.setVisible(false);
            scoreFrame.dispose();
            Score.deleteCanvas();
            SelectionBuffer.disposeEditFrame();
            scoreFrame = null;
            score = null;
        }
        JMSL.scheduler.stop();
        JMSL.closeMusicDevices();
    }

    public static void main(String args[]) {

        JScoreToot02 test = new JScoreToot02();
        test.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                test.stop();
                System.exit(0);
            }
        });

        test.init();
        test.start();
        test.pack();
        test.setVisible(true);
    }

}