package jmsltutorial;

import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;

import com.jsyn.instruments.SubtractiveSynthVoice;
import com.softsynth.jmsl.JMSL;
import com.softsynth.jmsl.JMSLMixerContainer;
import com.softsynth.jmsl.MusicShape;
import com.softsynth.jmsl.jsyn2.JSynMusicDevice;
import com.softsynth.jmsl.jsyn2.JSynUnitVoiceInstrument;
import com.softsynth.jmsl.view.MusicShapeEditor;

/**
 * Test JSynUnitVoiceInstrument by putting it into a simple 4 dimensional
 * MusicShape
 * 
 * Uses pure Java JSyn API
 * 
 * @author Nick Didkovsky, Dec. 2, 2024
 */

public class TestSubtractiveSynthVoiceInstrument extends JFrame {

    JSynUnitVoiceInstrument ins;
    MusicShape s;
    JMSLMixerContainer mixer;

    void initJSyn() {
        JMSL.clock.setAdvance(0.1);
        JSynMusicDevice dev = JSynMusicDevice.instance();
        dev.edit(new Frame());
        dev.open();
    }

    void buildInstrumentAndMixer() {
        ins = new JSynUnitVoiceInstrument(8, SubtractiveSynthVoice.class.getName());
        mixer = new JMSLMixerContainer();
        mixer.start();
        mixer.addInstrument(ins);
    }

    void buildMusicShape() {
        // Build a MusicShape standard dimension name space:
        // duration, pitch, amplitude, hold

        s = new MusicShape(4);
        s.useStandardDimensionNameSpace();
        s.add(0.5, 66, 0.35, 1.66);
        s.add(0.75, 77, 0.35, 2.66);
        s.add(0.25, 48, 0.35, 3.66);
        s.add(0.75, 77, 0.35, 1.66);
        s.add(0.25, 48, 0.35, 2.66);
        // put our instrument into the MusicShape
        s.setInstrument(ins);
        // make it repeat a long time, and launch it
        s.setRepeats(1000);
    }

    void go() {
        s.launch(JMSL.now());
    }

    void buildLayout() {
        // create a graphical editor to play with the shape data in realtime
        MusicShapeEditor se = new MusicShapeEditor();
        se.addMusicShape(s);

        // add the MusicShapeEditor and mixer panel to the JFrame
        add(BorderLayout.NORTH, se.getComponent());
        add(BorderLayout.SOUTH, mixer.getPanAmpControlPanel());
    }

    public static void main(String args[]) {

        TestSubtractiveSynthVoiceInstrument test = new TestSubtractiveSynthVoiceInstrument();
        test.setLayout(new BorderLayout());
        test.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                JMSL.closeMusicDevices();
                System.exit(0);
            }
        });

        test.initJSyn();
        test.buildInstrumentAndMixer();
        test.buildMusicShape();
        test.buildLayout();

        test.pack();
        test.setVisible(true);
        
        test.go();
        
    }

}
